import { LanguageClient } from './LanguageClient';
import { clientFacet, fileUriFacet, textDocumentSync, lspLinter } from './extensions';
/**
 * The client capabilities are how we tell the language server what
 * features we support so that they have the opportunity to skip doing
 * things that the client does not support. Everything is false by default,
 * but we migth need to change that and this is where we'll do it.
 */
const clientCapabilities = {};
const defaultLogger = console.log.bind(console);
// There is one LanguageClient
// There is one LanguageServer
// There are many CodeMirror instances
export class CodeMirrorLanguageClient {
    constructor(worker, { log = defaultLogger } = {}) {
        this.worker = worker;
        this.client = new LanguageClient(worker, {
            clientCapabilities,
            log,
        });
        this.worker = worker;
    }
    async start() {
        await this.client.start();
    }
    async stop() {
        try {
            await this.client.stop();
        }
        finally {
            this.worker.terminate();
        }
    }
    extension(fileUri) {
        return [clientFacet.of(this.client), fileUriFacet.of(fileUri), textDocumentSync, lspLinter];
    }
}
//# sourceMappingURL=CodeMirrorLanguageClient.js.map