(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "./LanguageClient", "./extensions"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.CodeMirrorLanguageClient = void 0;
    const LanguageClient_1 = require("./LanguageClient");
    const extensions_1 = require("./extensions");
    /**
     * The client capabilities are how we tell the language server what
     * features we support so that they have the opportunity to skip doing
     * things that the client does not support. Everything is false by default,
     * but we migth need to change that and this is where we'll do it.
     */
    const clientCapabilities = {};
    const defaultLogger = console.log.bind(console);
    // There is one LanguageClient
    // There is one LanguageServer
    // There are many CodeMirror instances
    class CodeMirrorLanguageClient {
        constructor(worker, { log = defaultLogger } = {}) {
            this.worker = worker;
            this.client = new LanguageClient_1.LanguageClient(worker, {
                clientCapabilities,
                log,
            });
            this.worker = worker;
        }
        async start() {
            await this.client.start();
        }
        async stop() {
            try {
                await this.client.stop();
            }
            finally {
                this.worker.terminate();
            }
        }
        extension(fileUri) {
            return [extensions_1.clientFacet.of(this.client), extensions_1.fileUriFacet.of(fileUri), extensions_1.textDocumentSync, extensions_1.lspLinter];
        }
    }
    exports.CodeMirrorLanguageClient = CodeMirrorLanguageClient;
});
//# sourceMappingURL=CodeMirrorLanguageClient.js.map